#include <owl\owlpch.h>
#pragma hdrstop

#include "draglb.h"

DEFINE_RESPONSE_TABLE1(TDragListBox, TListBox)
	EV_WM_LBUTTONDOWN,
	EV_WM_LBUTTONUP,
	EV_WM_MOUSEMOVE,
END_RESPONSE_TABLE;

TDragListBox::TDragListBox(TWindow * par_win, int res_id)
	: TListBox(par_win, res_id),
	DragCursor(0),
	NoDragCursor(0),
	MouseDown(false),
	CurrentTop(0),
	CurrentSelection(0),
	ParWin(par_win)
{
	DragCursor = ::LoadCursor(GetModule()->GetInstance(),
		MAKEINTRESOURCE(IDC_DRAGSINGLE));
	NoDragCursor = ::LoadCursor(GetModule()->GetInstance(),
		MAKEINTRESOURCE(IDC_NODRAG));
}

TDragListBox::~TDragListBox (void)
{
	DestroyCursor(DragCursor);
	DestroyCursor(NoDragCursor);
}

void
TDragListBox::SetupWindow (void)
{
	TListBox::SetupWindow();
	Height = GetItemHeight(0);
}

void
TDragListBox::EvLButtonDown (uint modKeys, TPoint & pt)
{
	TRect rect;

	TListBox::EvLButtonDown(modKeys, pt);

	if (GetCount() == 1)
		return;

	rect = GetClientRect();
	CurrentTop = GetTopIndex();
	int index = pt.y / Height;
	CurrentSelection = index + CurrentTop;
	GetItemRect(index, CurrentEntryRect);
	CurrentEntryRect.bottom = CurrentEntryRect.top + Height;
	MouseDown = true;
	SetCapture();

	rect = GetWindowRect();
	rect.bottom++;
	ClipCursor(&rect);
}

void
TDragListBox::EvLButtonUp (uint modKeys, TPoint & pt)
{
	if (!MouseDown)
	{
		TListBox::EvLButtonUp(modKeys, pt);
		return;
	}

	MouseDown = false;
	ReleaseCapture();
	ClipCursor(NULL);
	int newPosition = (pt.y / Height + CurrentTop);
	int entries = GetCount();
	if (newPosition == entries)
		newPosition = -1;

	char buf[256];
	GetString(buf, CurrentSelection);
	DeleteString(CurrentSelection);
	int result = InsertString(buf, newPosition);
	SetSelIndex(result);
   TListBox::EvLButtonUp(modKeys, pt);
}

void
TDragListBox::EvMouseMove (uint modKeys, TPoint & pt)
{
	if (MouseDown)
	{
		if (!PtInRect(&CurrentEntryRect, pt))
			::SetCursor(DragCursor);

		TRect rect = GetClientRect();
		int entries = (GetCount());
		int bottom = rect.bottom / Height + CurrentTop;

		if (pt.y < rect.top && CurrentTop > 0)
		{
			SetCaretIndex(CurrentTop - 1, false);
			CurrentTop--;
		}
		else if (pt.y > rect.bottom && bottom < entries)
		{
			SetTopIndex(CurrentTop + 1);
			SetCaretIndex(bottom + 1, false);
			CurrentTop++;
		}
		else
		{
			SetCaretIndex(pt.y / Height + CurrentTop, false);
		}
		TListBox::EvMouseMove(modKeys, pt);
	}
	else
		TListBox::EvMouseMove(modKeys, pt);
}


