/*  Project test
    
    Copyright  1996. All Rights Reserved.

    SUBSYSTEM:    test.exe Application
    FILE:         test.cpp
    AUTHOR:       Jonathan Schafer


    OVERVIEW
    ========
    Source file for implementation of testApp (TApplication).      
*/


#include <owl\owlpch.h>
#pragma hdrstop


#include "test.h"
#include "testwndw.h"                        // Definition of client class.
#include "tabotdlg.h"                        // Definition of about dialog.
#include "listdlg.h"

//{{testApp Implementation}}


//
// Build a response table for all messages/commands handled
// by the application.
//
DEFINE_RESPONSE_TABLE1(testApp, TApplication)
//{{testAppRSP_TBL_BEGIN}}
    EV_COMMAND(CM_FILENEW, CmFileNew),
    EV_COMMAND(CM_FILEOPEN, CmFileOpen),
	 EV_COMMAND(CM_SHOWLISTDLG, CmShowListDlg),
	 EV_COMMAND(CM_HELPABOUT, CmHelpAbout),
//{{testAppRSP_TBL_END}}
END_RESPONSE_TABLE;


//////////////////////////////////////////////////////////
// testApp
// =====
//
testApp::testApp () : TApplication("Test")
{

    // Common file file flags and filters for Open/Save As dialogs.  Filename and directory are
    // computed in the member functions CmFileOpen, and CmFileSaveAs.
    FileData.Flags = OFN_FILEMUSTEXIST | OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT;
	 FileData.SetFilter("All Files (*.*)|*.*|");

    // INSERT>> Your constructor code here.
}


testApp::~testApp ()
{
    // INSERT>> Your destructor code here.
}


//////////////////////////////////////////////////////////
// testApp
// =====
// Application intialization.
//
void testApp::InitMainWindow ()
{
    if (nCmdShow != SW_HIDE)
        nCmdShow = (nCmdShow != SW_SHOWMINNOACTIVE) ? SW_SHOWNORMAL : nCmdShow;

    SDIDecFrame *frame = new SDIDecFrame(0, GetName(), 0, false);

    //
    // Assign ICON w/ this application.
    //
    frame->SetIcon(this, IDI_SDIAPPLICATION);

    //
    // Menu associated with window and accelerator table associated with table.
    //
	 frame->AssignMenu(SDI_MENU);
    
    //
    // Associate with the accelerator table.
    //
    frame->Attr.AccelTable = SDI_MENU;

  
    SetMainWindow(frame);

    frame->SetMenuDescr(TMenuDescr(SDI_MENU));

    //
    // Windows 3-D controls.
    //
    EnableCtl3d(true);
}


//////////////////////////////////////////////////////////
// testApp
// ===========
// Menu File New command
void testApp::CmFileNew ()
{
}


//////////////////////////////////////////////////////////
// testApp
// ===========
// Menu File Open command
void testApp::CmFileOpen ()
{
    //
    // Display standard Open dialog box to select a file name.
    //
    *FileData.FileName = 0;

    testWindow *client = TYPESAFE_DOWNCAST(GetMainWindow()->GetClientWindow(), testWindow);     // Client window for the frame.
    if (client->CanClose())
        if (TFileOpenDialog(GetMainWindow(), FileData).Execute() == IDOK)
            OpenFile();
}


void testApp::OpenFile (const char *fileName)
{
	 if (fileName)
		  strcpy(FileData.FileName, fileName);

}

void
testApp::CmShowListDlg (void)
{
	TListDlg(GetMainWindow(), IDD_LISTBOX).Execute();
}


//{{SDIDecFrame Implementation}}


SDIDecFrame::SDIDecFrame (TWindow *parent, const char far *title, TWindow *clientWnd, bool trackMenuSelection, TModule *module)
    : TDecoratedFrame(parent, title, clientWnd == 0 ? new testWindow(0, "") : clientWnd, trackMenuSelection, module)
{
    // INSERT>> Your constructor code here.

}


SDIDecFrame::~SDIDecFrame ()
{
    // INSERT>> Your destructor code here.

}


//////////////////////////////////////////////////////////
// testApp
// ===========
// Menu Help About test.exe command
void testApp::CmHelpAbout ()
{
    //
    // Show the modal dialog.
    //
    TAboutDlg(MainWindow).Execute();
}
int OwlMain (int , char* [])
{
    try {
        testApp    app;
        return app.Run();
    }
    catch (xmsg& x) {
        ::MessageBox(0, x.why().c_str(), "Exception", MB_OK);
    }

    return -1;
}
